@@ -4,11 +4,14 @@ import errno
 import mimetypes
 import socket
 import sys
+from unittest import mock
 
-from mock import patch
+import six
 
 import cherrypy
-from cherrypy._cpcompat import HTTPConnection, HTTPSConnection, ntob, py3k
+from cherrypy._cpcompat import HTTPConnection, HTTPSConnection, ntob
+
+from cherrypy.test import helper
 
 
 def encode_multipart_formdata(files):
@@ -33,29 +36,28 @@ def encode_multipart_formdata(files):
     return content_type, body
 
 
-from cherrypy.test import helper
-
-
 class HTTPTests(helper.CPWebCase):
 
     def make_connection(self):
-        if self.scheme == "https":
+        if self.scheme == 'https':
             return HTTPSConnection('%s:%s' % (self.interface(), self.PORT))
         else:
             return HTTPConnection('%s:%s' % (self.interface(), self.PORT))
 
+    @staticmethod
     def setup_server():
         class Root:
 
+            @cherrypy.expose
             def index(self, *args, **kwargs):
-                return "Hello world!"
-            index.exposed = True
+                return 'Hello world!'
 
+            @cherrypy.expose
+            @cherrypy.config(**{'request.process_request_body': False})
             def no_body(self, *args, **kwargs):
-                return "Hello world!"
-            no_body.exposed = True
-            no_body._cp_config = {'request.process_request_body': False}
+                return 'Hello world!'
 
+            @cherrypy.expose
             def post_multipart(self, file):
                 """Return a summary ("a * 65536\nb * 65536") of the uploaded
                 file.
@@ -69,17 +71,16 @@ class HTTPTests(helper.CPWebCase):
                         count += 1
                     else:
                         if count:
-                            if py3k:
+                            if six.PY3:
                                 curchar = chr(curchar)
-                            summary.append("%s * %d" % (curchar, count))
+                            summary.append('%s * %d' % (curchar, count))
                         count = 1
                         curchar = c
                 if count:
-                    if py3k:
+                    if six.PY3:
                         curchar = chr(curchar)
-                    summary.append("%s * %d" % (curchar, count))
-                return ", ".join(summary)
-            post_multipart.exposed = True
+                    summary.append('%s * %d' % (curchar, count))
+                return ', '.join(summary)
 
             @cherrypy.expose
             def post_filename(self, myfile):
@@ -88,7 +89,6 @@ class HTTPTests(helper.CPWebCase):
 
         cherrypy.tree.mount(Root())
         cherrypy.config.update({'server.max_request_body_size': 30000000})
-    setup_server = staticmethod(setup_server)
 
     def test_no_content_length(self):
         # "The presence of a message-body in a request is signaled by the
@@ -99,7 +99,7 @@ class HTTPTests(helper.CPWebCase):
         # the request is of method POST, this should be OK because we set
         # request.process_request_body to False for our handler.
         c = self.make_connection()
-        c.request("POST", "/no_body")
+        c.request('POST', '/no_body')
         response = c.getresponse()
         self.body = response.fp.read()
         self.status = str(response.status)
@@ -109,24 +109,26 @@ class HTTPTests(helper.CPWebCase):
         # Now send a message that has no Content-Length, but does send a body.
         # Verify that CP times out the socket and responds
         # with 411 Length Required.
-        if self.scheme == "https":
+        if self.scheme == 'https':
             c = HTTPSConnection('%s:%s' % (self.interface(), self.PORT))
         else:
             c = HTTPConnection('%s:%s' % (self.interface(), self.PORT))
-        if hasattr(c, '_set_content_length'): # python 2.6 doesn't have it
-            with patch.object(c, '_set_content_length'):
-                c.request("POST", "/")
-        else:
-            c.request("POST", "/")
+
+        # `_get_content_length` is needed for Python 3.6+
+        with mock.patch.object(c, '_get_content_length', lambda body, method: None, create=True):
+            # `_set_content_length` is needed for Python 2.7-3.5
+            with mock.patch.object(c, '_set_content_length', create=True):
+                c.request('POST', '/')
+
         response = c.getresponse()
         self.body = response.fp.read()
         self.status = str(response.status)
         self.assertStatus(411)
 
     def test_post_multipart(self):
-        alphabet = "abcdefghijklmnopqrstuvwxyz"
+        alphabet = 'abcdefghijklmnopqrstuvwxyz'
         # generate file contents for a large post
-        contents = "".join([c * 65536 for c in alphabet])
+        contents = ''.join([c * 65536 for c in alphabet])
 
         # encode as multipart form data
         files = [('file', 'file.txt', contents)]
@@ -145,14 +147,17 @@ class HTTPTests(helper.CPWebCase):
         self.body = response.fp.read()
         self.status = str(response.status)
         self.assertStatus(200)
-        self.assertBody(", ".join(["%s * 65536" % c for c in alphabet]))
+        self.assertBody(', '.join(['%s * 65536' % c for c in alphabet]))
 
-    def test_post_filename_with_commas(self):
-        '''Testing that we can handle filenames with commas. This was
-        reported as a bug in:
-           https://github.com/cherrypy/cherrypy/issues/1146/'''
+    def test_post_filename_with_special_characters(self):
+        '''Testing that we can handle filenames with special characters. This
+        was reported as a bug in:
+           https://github.com/cherrypy/cherrypy/issues/1146/
+           https://github.com/cherrypy/cherrypy/issues/1397'''
         # We'll upload a bunch of files with differing names.
-        for fname in ['boop.csv', 'foo, bar.csv', 'bar, xxxx.csv', 'file"name.csv']:
+        fnames = ['boop.csv', 'foo, bar.csv', 'bar, xxxx.csv', 'file"name.csv',
+                'file;name.csv', 'file; name.csv']
+        for fname in fnames:
             files = [('myfile', fname, 'yunyeenyunyue')]
             content_type, body = encode_multipart_formdata(files)
             body = body.encode('Latin-1')
@@ -172,8 +177,8 @@ class HTTPTests(helper.CPWebCase):
             self.assertBody(fname)
 
     def test_malformed_request_line(self):
-        if getattr(cherrypy.server, "using_apache", False):
-            return self.skip("skipped due to known Apache differences...")
+        if getattr(cherrypy.server, 'using_apache', False):
+            return self.skip('skipped due to known Apache differences...')
 
         # Test missing version in Request-Line
         c = self.make_connection()
@@ -187,14 +192,18 @@ class HTTPTests(helper.CPWebCase):
             response = c.response_class(c.sock, method='GET')
         response.begin()
         self.assertEqual(response.status, 400)
-        self.assertEqual(response.fp.read(22), ntob("Malformed Request-Line"))
+        self.assertEqual(response.fp.read(22), ntob('Malformed Request-Line'))
         c.close()
 
     def test_request_line_split_issue_1220(self):
-        Request_URI = "/index?intervenant-entreprise-evenement_classaction=evenement-mailremerciements&_path=intervenant-entreprise-evenement&intervenant-entreprise-evenement_action-id=19404&intervenant-entreprise-evenement_id=19404&intervenant-entreprise_id=28092"
-        self.assertEqual(len("GET %s HTTP/1.1\r\n" % Request_URI), 256)
+        Request_URI = (
+            '/index?intervenant-entreprise-evenement_classaction=evenement-mailremerciements'
+            '&_path=intervenant-entreprise-evenement&intervenant-entreprise-evenement_action-id=19404'
+            '&intervenant-entreprise-evenement_id=19404&intervenant-entreprise_id=28092'
+        )
+        self.assertEqual(len('GET %s HTTP/1.1\r\n' % Request_URI), 256)
         self.getPage(Request_URI)
-        self.assertBody("Hello world!")
+        self.assertBody('Hello world!')
 
     def test_malformed_header(self):
         c = self.make_connection()
@@ -208,24 +217,24 @@ class HTTPTests(helper.CPWebCase):
         self.status = str(response.status)
         self.assertStatus(400)
         self.body = response.fp.read(20)
-        self.assertBody("Illegal header line.")
+        self.assertBody('Illegal header line.')
 
     def test_http_over_https(self):
         if self.scheme != 'https':
-            return self.skip("skipped (not running HTTPS)... ")
+            return self.skip('skipped (not running HTTPS)... ')
 
         # Try connecting without SSL.
         conn = HTTPConnection('%s:%s' % (self.interface(), self.PORT))
-        conn.putrequest("GET", "/", skip_host=True)
-        conn.putheader("Host", self.HOST)
+        conn.putrequest('GET', '/', skip_host=True)
+        conn.putheader('Host', self.HOST)
         conn.endheaders()
-        response = conn.response_class(conn.sock, method="GET")
+        response = conn.response_class(conn.sock, method='GET')
         try:
             response.begin()
             self.assertEqual(response.status, 400)
             self.body = response.read()
-            self.assertBody("The client sent a plain HTTP request, but this "
-                            "server only speaks HTTPS on this port.")
+            self.assertBody('The client sent a plain HTTP request, but this '
+                            'server only speaks HTTPS on this port.')
         except socket.error:
             e = sys.exc_info()[1]
             # "Connection reset by peer" is also acceptable.
@@ -237,12 +246,12 @@ class HTTPTests(helper.CPWebCase):
         c = HTTPConnection('%s:%s' % (self.interface(), self.PORT))
         c._output(ntob('gjkgjklsgjklsgjkljklsg'))
         c._send_output()
-        response = c.response_class(c.sock, method="GET")
+        response = c.response_class(c.sock, method='GET')
         try:
             response.begin()
             self.assertEqual(response.status, 400)
             self.assertEqual(response.fp.read(22),
-                             ntob("Malformed Request-Line"))
+                             ntob('Malformed Request-Line'))
             c.close()
         except socket.error:
             e = sys.exc_info()[1]
